<?php
/*
Plugin Name: EasyPay for WooCommerce
Plugin URI: https://ssl.easypay.by/module/
Description: EasyPay payment gateway for WooCommerce.
Version: 1.0
Author: EasyPay
Author URI: https://ssl.easypay.by

	Copyright: � 2009-2016 EasyPay Inc.
	License: GNU General Public License v3.0
	License URI: http://www.gnu.org/licenses/gpl-3.0.html
*/

if ( ! defined( 'ABSPATH' ) )
	exit;

add_action('plugins_loaded', 'woocommerce_EasyPay_init');

function woocommerce_EasyPay_init() {
	
	if (!class_exists('WC_Payment_Gateway'))
		return; 
	if (class_exists('WC_EasyPay'))
		return;
	
	/**
	 * Gateway class
	*/
	class WC_EasyPay extends WC_Payment_Gateway {
		
		public function __construct() {
			
			$this->id				= 'easypay';
			$this->method_title     = __( 'EasyPay', 'woocommerce' );
			$this->icon				= "https://ssl.easypay.by/imgs/icons/easypay_icon.gif";
			$this->liveurl			= 'https://ssl.easypay.by/weborder/?EP_Module=wp_woocommerce';
			$this->has_fields 		= false;
			
			$this->init_form_fields();
			$this->init_settings();
			
			$this->title 	   = $this->settings['title'];
			$this->mer_no      = $this->settings['mer_no'];
			$this->web_key     = $this->settings['web_key'];
			$this->debug       = $this->settings['debug'];
			$this->description = $this->settings['description'];
			$this->expires     = $this->settings['expires'];
			$this->comment     = $this->settings['comment'];
			
			add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );
			
			add_action('woocommerce_thankyou_'.$this->id, array( $this, 'thankyou_page' ) );
			add_action('woocommerce_receipt_'.$this->id, array( $this, 'receipt_page' ));
			
			add_action('woocommerce_api_wc_easypay', array($this, 'check_EasyPay_response'));
			
			
		} 
		
		function init_form_fields() {
			
			$this->form_fields = array(
				'enabled' => array(
								'title' => __( 'Включить/Выключить', 'woocommerce' ), 
								'type' => 'checkbox', 
								'label' => __( 'Включен EasyPay', 'woocommerce' ), 
								'default' => 'no'
							), 
				'title' => array(
								'title' => __( 'Название', 'woocommerce' ), 
								'type' => 'text', 
								'description' => __( 'Это название, которое пользователь видит во время оплаты.', 'woocommerce' ), 
								'default' => __( 'EasyPay', 'woocommerce' )
				),
				'mer_no' => array(
								'title' => __( 'Номер Поставщика', 'woocommerce' ), 
								'type' => 'text', 
								'description' => __( 'Пожалуйста, введите номер Поставщика.', 'woocommerce' ), 
								'default' => ''
				),
				'web_key' => array(
								'title' => __( 'Ключ для подписи счетов', 'woocommerce' ), 
								'type' => 'text', 
								'description' => __( 'Ключ для подписи счетов web_key.', 'woocommerce' ), 
								'default' => ''
				),
				'expires' => array(
								'title' => __( 'Срок действия счета', 'woocommerce' ), 
								'type' => 'text', 
								'description' => __( 'Число от 1 до 30, если период задан в днях или от 600 до 3600*24, если период задан в секундах.', 'woocommerce' ), 
								'default' => __( '3', 'woocommerce' )
				),
				'debug' => array(
								'title' => __( 'Режим отладки', 'woocommerce' ), 
								'type' => 'checkbox',
								'label' => __( 'Включен', 'woocommerce' ), 
								'description' => __( 'В этом режиме выводится подробная информация о передаваемых данных.', 'woocommerce' ), 
								'default' => 'no'
				),
				'description' => array(
								'title' => __( 'Описание метода оплаты', 'woocommerce' ), 
								'type' => 'textarea', 
								'description' => __( 'Описание метода оплаты, которое клиент будет видеть на вашем сайте.', 'woocommerce' ), 
								'default' => __( 'Оплата Visa, MasterCard', 'woocommerce' )
				),
				'comment' => array(
								'title' => __( 'Комментарий счета', 'woocommerce' ), 
								'type' => 'text', 
								'description' => __( 'Краткий комментарий счета. Формируется Поставщиком (не более 50 символов).', 'woocommerce' ), 
								'default' => ''
				)		
			);
		}
		
		/**
		 * Admin Panel Options
		**/
		public function admin_options() {
		
			echo '<h3>'.__('EasyPay', 'woocommerce').'</h3>';
			echo '<p>'.__('EasyPay Payment', 'woocommerce').'</p>';
			echo '<table class="form-table">';
			
			$this->generate_settings_html();
			echo '</table>';
		}
		
		function payment_fields() {
			if ($this->description) echo wpautop(wptexturize($this->description));
		}
		
		/**
		 * Receipt Page
		**/
		function receipt_page( $order ) {
			echo '<p>' . __('Спасибо за Ваш заказ, пожалуйста, нажмите кнопку ниже, чтобы оплатить.', 'woocommerce') . '</p>';
			echo $this->generate_EasyPay_form( $order );
		}
		
		/**
		 * Process the payment and return the result
		**/
		function process_payment( $order_id ) {
			$order = new WC_Order( $order_id );
			return array(
				'result' 	=> 'success',
				'redirect' => $order->get_checkout_payment_url( true )
			);
		}
		
		/**
		 * Check for valid EasyPay server callback
		**/
		function check_EasyPay_response() {
			global $woocommerce;
			if (isset($_GET['result']) && $_GET['result'] == 'notify') {		
				$order_mer_code		= isset($_POST['order_mer_code']) ? $_POST['order_mer_code'] : '';
				$sum				= isset($_POST['sum']) ? $_POST['sum'] : '';
				$mer_no				= isset($_POST['mer_no']) ? $_POST['mer_no'] : '';
				$card				= isset($_POST['card']) ? $_POST['card'] : '';
				$notify_signature	= isset($_POST['notify_signature']) ? $_POST['notify_signature'] : '';
				$purch_date			= isset($_POST['purch_date']) ? $_POST['purch_date'] : '';
				$web_key			= $this->web_key;
					
				$sign = md5($order_mer_code . $sum . $mer_no . $card . $purch_date . $web_key);

				$order = new WC_Order($order_mer_code);

					if ($notify_signature == $sign) { //проверка правильности подписи
						$order->payment_complete();//меняем статус на "Завершенный"
						$status = 'OK | payment received';
						header("HTTP/1.0 200 OK");
						print $status;
					} else { //подписи не совпадают
							  $status = 'FAILED | wrong notify signature'; 
							  header("HTTP/1.0 400 Bad Request");
							  print $status;
					}
					exit;
				}
		}
		
		function thankyou_page() {
			if ($this->description) {
				echo wpautop(wptexturize($this->description));
			}
			
			echo '<h2>'.__('Our Details', 'woocommerce').'</h2>';
			echo '<ul class="order_details ppay_details">';
			$fields = array(
				'ppay_number'=> __('EasyPay', 'woocommerce')
			);
			
			foreach ($fields as $key=>$value) :
				if(!empty($this->$key)) :
					echo '<li class="'.$key.'">'.$value.': <strong>'.wptexturize($this->$key).'</strong></li>';
				endif;
			endforeach;
			echo '</ul>';
		}
		
		function generate_EasyPay_form( $order_id ) {
			global $woocommerce;
			$order = new WC_Order($order_id);
		
			$action_adr		= $this->liveurl;
			$out_summ		= $order->order_total;
			$hash			= md5($this->mer_no . $this->web_key . $order_id . $out_summ);
			$this->debug	= ($this->debug == 'yes') ? 1 : 0;
			$success_url	= $this->get_return_url($order);
			$cancel_url		= $order->get_cancel_order_url();  

		$args = array(
			'EP_MerNo'       => $this->mer_no,
			'EP_OrderNo'     => $order_id,
			'EP_Sum'         => $out_summ,
			'EP_Expires'     => $this->expires,
			'EP_Comment'     => $this->comment,
			'EP_OrderInfo'   => "Заказ №$order_id",
			'EP_Hash'        => $hash,
			'EP_Success_URL' => $success_url,
			'EP_Cancel_URL'  => $cancel_url,
			'EP_Debug'       => $this->debug,
			'EP_Encoding'	 => "utf-8",
		);
		$args_array = array();
		foreach ($args as $key => $value){
			$args_array[] = '<input type="hidden" name="' . esc_attr($key) . '" value="' . $value . '" />';
		}
		
		$woocommerce->cart->empty_cart();//Очищение корзины

		return
			'<form action="' . esc_url($action_adr) . '" method="POST" id="easypay_payment_form" >' . "\n".
			implode("\n", $args_array) . '<input type="submit" class="button alt" id="submit_easypay_payment_form" value="' . __('Оплатить', 'woocommerce') . '" /> <a class="button cancel" href="' . $order->get_cancel_order_url() . '">' . __('Отказаться от оплаты & вернуться в корзину', 'woocommerce') . '</a>' . "\n" . '</form>';
		}
	}
	
	/**
	 * Add the EasyPay gateway to WooCommerce
	**/
	function woocommerce_add_EasyPay_gateway($methods) {
		$methods[] = 'WC_EasyPay';
		return $methods;
	}
	
	add_filter('woocommerce_payment_gateways', 'woocommerce_add_EasyPay_gateway' );
}

?>